"use strict";

class MainSVM
{
	preAkiLoad(container)
	{
		const Logger = container.resolve("WinstonLogger");
		try {
		const Config = require('../Loader/loader.json');
		}
		catch (e)
		{	
				const Logger = container.resolve("WinstonLogger");
				Logger.error("SVM: SVM is lacking loader file or there is an error, mod is disabled");
				Logger.error("SVM: If it's Syntax error, edit it manually in loader.json or/and edit values with GFVE properly");
				Logger.error("SVM: If it can't find module(loader), run GFVE inside mod folder and create it, duh\n");
				Logger.error(e.message+"\n");
				return
		}
		const Config = require('../Loader/loader.json');
		const StaticRouterModService = container.resolve("StaticRouterModService");
		const HttpResponse = container.resolve("HttpResponseUtil");
		if (Config.Raids.SafeExit)
		{
		container.afterResolution("InraidCallbacks", (_t, result) => 
			{
				result.saveProgress = (url, info, sessionID) => 
				{
				if(info.exit == "left") 
					{
						info.exit = "runner"
					}
					const InraidController = container.resolve("InraidController");
					InraidController.saveProgress(info, sessionID);
				return HttpResponse.nullResponse();
				}
			},{frequency: "Always"});
		}
		if (Config.Raids.SaveGearAfterDeath)
		{
		container.afterResolution("InraidCallbacks", (_t, result) => 
			{
				result.saveProgress = (url, info, sessionID) => 
				{
				if(info.exit !== "survived") 
					{
						info.exit = "runner"
					}
					const InraidController = container.resolve("InraidController");
					InraidController.saveProgress(info, sessionID);
				return HttpResponse.nullResponse();
				}
			},{frequency: "Always"});
		}
		if (Config.Deprecated.SkillMax)
		{
			Logger.debug("SVM: Max Skills activated")
			StaticRouterModService.registerStaticRouter("MaxSkills", [
			{
				url: "/client/game/version/validate",
				action: (url, info, sessionID) =>
				{
					try
					{
						let pmcData = container.resolve("ProfileHelper").getPmcProfile(sessionID);
						for (let skills in pmcData.Skills.Common)
						{
							let skill = pmcData.Skills.Common[skills] //I think it could be done to reverse it, but just setting skill.Progress = 0 may still make them appear in skills tree
							switch (skill.Id)
							{
								case "BotReload":
									if (Config.Deprecated.BotReload)
									{
										skill.Progress = 5100;
									}
									break;
								case "BotSound":
									if (Config.Deprecated.BotSound)
									{
										skill.Progress = 5100;
									}
									break;
								default:
									skill.Progress = 5100;
									break;
							}
						}
						return HttpResponse.nullResponse();
					}
					catch (e)
					{
						Logger.error("Max Skills: Error spotted or New profile detected, Cancelling function" + e)
						return HttpResponse.nullResponse();
					}
				}
			}], "aki");
		}
		if (Config.CSM.DefaultPocket)
		{
			StaticRouterModService.registerStaticRouter("DefaultPockets",
				[
				{
					url: "/client/game/version/validate",
					action: (url, info, sessionID) =>
					{
						let pmcData = container.resolve("ProfileHelper").getPmcProfile(sessionID);
						try
						{
							pmcData.Inventory.items.forEach((item) =>
							{
								if (item.slotId == "Pockets")
								{
									item._tpl = "627a4e6b255f7527fb05a0f6";
								}
							})
							return HttpResponse.nullResponse();
						}
						catch (e)
						{
							Logger.error("Default Pockets: New profile detected, Cancelling function" + e)
							return HttpResponse.nullResponse();
						}
					}
				}], "aki");
		}
		if (Config.CSM.CustomPocket)
		{		
				StaticRouterModService.registerStaticRouter("CustomPocket",
					[
					{
						url: "/client/game/version/validate",
						action: (url, info, sessionID) =>
						{
							let pmcData = container.resolve("ProfileHelper").getPmcProfile(sessionID);
							try
							{
								pmcData.Inventory.items.forEach((item) =>
								{
									if (item.slotId == "Pockets")
									{
										item._tpl = "CustomPocket";
									}
								})
								return HttpResponse.nullResponse();
							}
							catch (e)
							{
								Logger.error("Bigger Pockets: New profile detected, Cancelling function" + e)
								return HttpResponse.nullResponse();
							}
						}
					}], "aki");
		}
		if (Config.Player.EnableHealth)
		{
			StaticRouterModService.registerStaticRouter("EditHealth",
				[
				{
					url: "/client/game/version/validate",
					action: (url, info, sessionID) =>
					{
						try
						{
							let pmcData = container.resolve("ProfileHelper").getPmcProfile(sessionID);
							pmcData.Health.BodyParts["Head"].Health.Maximum = Config.Player.Health.Head
							pmcData.Health.BodyParts["Chest"].Health.Maximum = Config.Player.Health.Chest
							pmcData.Health.BodyParts["Stomach"].Health.Maximum = Config.Player.Health.Stomach
							pmcData.Health.BodyParts["LeftArm"].Health.Maximum = Config.Player.Health.LeftArm
							pmcData.Health.BodyParts["LeftLeg"].Health.Maximum = Config.Player.Health.LeftLeg
							pmcData.Health.BodyParts["RightArm"].Health.Maximum = Config.Player.Health.RightArm
							pmcData.Health.BodyParts["RightLeg"].Health.Maximum = Config.Player.Health.RightLeg
							return HttpResponse.nullResponse();
						}
						catch (e)
						{
							Logger.error("SVM:Edit health - Unknown error occured" + e)
							return HttpResponse.nullResponse();
						}
					}
				}], "aki");
		}
		if( Config.Raids.EnableRaids)
		{
			if (Config.Raids.RaidEvents.RaidersEverywhere)
			{
				StaticRouterModService.registerStaticRouter("GenerateRaiders",
					[
					{
						url: "/client/game/bot/generate",
						action: (url, info, sessionID) =>
						{
							const BotController = container.resolve("BotController");
								for (let type in info.conditions)
								{
									let roles = info.conditions[type]
									roles.Role = "pmcBot"
									roles.Difficulty = "impossible"
								}
								return HttpResponse.getBody(BotController.generate(sessionID,info));
						}
					}], "aki");
			}
			if (Config.Raids.RaidEvents.CultistsEverywhere)
			{
				//Inraid.raidMenuSettings.taggedAndCursed = true;
				StaticRouterModService.registerStaticRouter("GenerateCultists",
					[
					{
						url: "/client/game/bot/generate",
						action: (url, info, sessionID) =>
						{
							const BotController = container.resolve("BotController");
								for (let type in info.conditions)
								{
									let roles = info.conditions[type]
									roles.Role = "sectantwarrior"
									roles.Difficulty = "hard"
								}
								return HttpResponse.getBody(BotController.generate(sessionID,info));
						}
					}], "aki");
			}
		}
	}
	 postDBLoad(container)
	{
		const Logger = container.resolve("WinstonLogger");
		try {
		const Config = require('../Loader/loader.json');
		}
		catch (e)
		{
		return
		}
		//Config variables to asset for funcs.
		const Config = require('../Loader/loader.json');
		//DB redirects
		const DB = container.resolve("DatabaseServer").getTables();
		const hideout = DB.hideout;
		const locations = DB.locations;
		const traders = DB.traders;
		const Quests = DB.templates.quests;
		const suits = DB.templates.customization;
		const items = DB.templates.items;
		const globals = DB.globals.config;
		// Redirects to server internal configs.
		const configServer = container.resolve("ConfigServer");
		const Inraid = configServer.getConfig("aki-inraid");
		const Repair = configServer.getConfig("aki-repair");
		const locs = configServer.getConfig("aki-location");
		const Airdrop = configServer.getConfig("aki-airdrop");
		const Ragfair = configServer.getConfig("aki-ragfair");
		const Insurance = configServer.getConfig("aki-insurance");
		const Health = configServer.getConfig("aki-health");
		const Bots = configServer.getConfig("aki-bot");
		const Quest = configServer.getConfig("aki-quest");
		const hideoutC = configServer.getConfig("aki-hideout");
		const WeatherValues = configServer.getConfig("aki-weather");
		const trader = configServer.getConfig("aki-trader");
		const Inventory = configServer.getConfig("aki-inventory");
		const BL = Config.BL;
		const Bot = DB.bots.types
		//First initialising loggers
		Logger.log(`SVM 1.5.5 has awoken, EmuTarkovRC wishes you a good day`, "blue");
		if (Config.PresetName != "" && Config.PresetName != undefined)
		{
			Logger.log("SVM Preset - " + Config.PresetName + " - successfully loaded", "blue");
		}
		//############## RAGFAIR SECTION ###############
		if (Config.Fleamarket.EnableFleamarket)
		{
			Logger.debug("SVM:Fleamarket settings enabled")
			if(Config.Fleamarket.EnableFleamarket)
			{
				Ragfair.dynamic.blacklist.enableBsgList = !Config.Fleamarket.DisableBSGList;
				Ragfair.sell.fees = Config.Fleamarket.PlayerOffers.EnableFees;
				Ragfair.sell.chance.base = Config.Fleamarket.PlayerOffers.Sell_chance;
				Ragfair.sell.chance.underpriced = Config.Fleamarket.PlayerOffers.Sell_underprice;
				Ragfair.sell.chance.overprices = Config.Fleamarket.PlayerOffers.Sell_overprice;
				Ragfair.sell.time.base = Config.Fleamarket.PlayerOffers.Tradeoffer_avg;
				Ragfair.sell.time.max = Config.Fleamarket.PlayerOffers.Tradeoffer_max;
				Ragfair.sell.time.min = Config.Fleamarket.PlayerOffers.Tradeoffer_min;
				Ragfair.sell.reputation.gain = Config.Fleamarket.PlayerOffers.Rep_gain;
				Ragfair.sell.reputation.loss = Config.Fleamarket.PlayerOffers.Rep_loss;
				//Dynamic offers
				Ragfair.dynamic.expiredOfferThreshold = Config.Fleamarket.DynamicOffers.ExpireThreshold;
				//Min-Max
				Ragfair.dynamic.offerItemCount.min = Config.Fleamarket.DynamicOffers.PerOffer_min;
				Ragfair.dynamic.offerItemCount.max = Config.Fleamarket.DynamicOffers.PerOffer_max;
				Ragfair.dynamic.rating.min = Config.Fleamarket.DynamicOffers.Rating_min;
				Ragfair.dynamic.rating.max = Config.Fleamarket.DynamicOffers.Rating_max;
				Ragfair.dynamic.price.min = Config.Fleamarket.DynamicOffers.Price_min;
				Ragfair.dynamic.price.max = Config.Fleamarket.DynamicOffers.Price_max;
				Ragfair.dynamic.endTimeSeconds.min = Config.Fleamarket.DynamicOffers.Time_min;
				Ragfair.dynamic.endTimeSeconds.max = Config.Fleamarket.DynamicOffers.Time_max;
				Ragfair.dynamic.condition.min = Config.Fleamarket.DynamicOffers.Condition_min;
				Ragfair.dynamic.condition.max = Config.Fleamarket.DynamicOffers.Condition_max;
				Ragfair.dynamic.nonStackableCount.min = Config.Fleamarket.DynamicOffers.NonStack_min;
				Ragfair.dynamic.nonStackableCount.max = Config.Fleamarket.DynamicOffers.NonStack_max;
				Ragfair.dynamic.stackablePercent.min = Config.Fleamarket.DynamicOffers.Stack_min;
				Ragfair.dynamic.stackablePercent.max = Config.Fleamarket.DynamicOffers.Stack_max;
				//Currencies
				Ragfair.dynamic.currencies["5449016a4bdc2d6f028b456f"] = Config.Fleamarket.DynamicOffers.Roubleoffers;
				Ragfair.dynamic.currencies["5696686a4bdc2da3298b456a"] = Config.Fleamarket.DynamicOffers.Dollaroffers;
				Ragfair.dynamic.currencies["569668774bdc2da2298b4568"] = Config.Fleamarket.DynamicOffers.Eurooffers;
				//Trader static offers
				Ragfair.traders["54cb50c76803fa8b248b4571"] = Config.Fleamarket.TraderStaticOffers.Praporoffers;
				Ragfair.traders["54cb57776803fa99248b456e"] = Config.Fleamarket.TraderStaticOffers.Therapistoffers;
				Ragfair.traders["579dc571d53a0658a154fbec"] = Config.Fleamarket.TraderStaticOffers.Fenceoffers;
				Ragfair.traders["58330581ace78e27b8b10cee"] = Config.Fleamarket.TraderStaticOffers.SkierOffers;
				Ragfair.traders["5935c25fb3acc3127c3d8cd9"] = Config.Fleamarket.TraderStaticOffers.Peacekeeperoffers;
				Ragfair.traders["5a7c2eca46aef81a7ca2145d"] = Config.Fleamarket.TraderStaticOffers.Mechanicoffers;
				Ragfair.traders["5ac3b934156ae10c4430e83c"] = Config.Fleamarket.TraderStaticOffers.Ragmanoffers;
				Ragfair.traders["5c0647fdd443bc2504c2d371"] = Config.Fleamarket.TraderStaticOffers.Jaegeroffers;
				Ragfair.traders["ragfair"] = Config.Fleamarket.TraderStaticOffers.AllOffers;
			}
		}
		//############## LOOT SECTION ##################
		if (Config.Loot.EnableLoot)
		{
			Logger.debug("SVM:Loot settings enabled")
			//loose loot mults
			locs.looseLootMultiplier.bigmap = Config.Loot.Locations.Bigmap_mult;
			locs.looseLootMultiplier.factory4_day = Config.Loot.Locations.FactoryDay_mult;
			locs.looseLootMultiplier.factory4_night = Config.Loot.Locations.FactoryNight_mult;
			locs.looseLootMultiplier.interchange = Config.Loot.Locations.Interchange_mult;
			locs.looseLootMultiplier.laboratory = Config.Loot.Locations.Laboratory_mult;
			locs.looseLootMultiplier.rezervbase = Config.Loot.Locations.Reserve_mult;
			locs.looseLootMultiplier.shoreline = Config.Loot.Locations.Shoreline_mult;
			locs.looseLootMultiplier.woods = Config.Loot.Locations.Woods_mult;
			locs.looseLootMultiplier.lighthouse = Config.Loot.Locations.Lighthouse_mult;
			//container loot mults
			locs.staticLootMultiplier.bigmap = Config.Loot.Locations.Bigmap_conmult;
			locs.staticLootMultiplier.factory4_day = Config.Loot.Locations.FactoryDay_conmult;
			locs.staticLootMultiplier.factory4_night = Config.Loot.Locations.FactoryNight_conmult;
			locs.staticLootMultiplier.interchange = Config.Loot.Locations.Interchange_conmult;
			locs.staticLootMultiplier.laboratory = Config.Loot.Locations.Laboratory_conmult;
			locs.staticLootMultiplier.rezervbase = Config.Loot.Locations.Reserve_conmult;
			locs.staticLootMultiplier.shoreline = Config.Loot.Locations.Shoreline_conmult;
			locs.staticLootMultiplier.woods = Config.Loot.Locations.Woods_conmult;
			locs.staticLootMultiplier.lighthouse = Config.Loot.Locations.Lighthouse_conmult;
			//############## AIRDROPS SECTION ##################
			/*
			Airdrop.airdropMinStartTimeSeconds = Config.Loot.Airdrops.AirtimeMin;
			Airdrop.airdropMaxStartTimeSeconds = Config.Loot.Airdrops.AirtimeMax;
			Airdrop.airdropMinOpenHeight = Config.Loot.Airdrops.DropMin;
			Airdrop.airdropMaxOpenHeight = Config.Loot.Airdrops.DropMax;
			Airdrop.planeMinFlyHeight = Config.Loot.Airdrops.FlyMin;
			Airdrop.planeMaxFlyHeight = Config.Loot.Airdrops.FlyMax;
			Airdrop.airdropChancePercent.rezervbase = Config.Loot.Airdrops.Reserve_air;
			Airdrop.airdropChancePercent.shoreline = Config.Loot.Airdrops.Shoreline_air;
			Airdrop.airdropChancePercent.woods = Config.Loot.Airdrops.Woods_air;
			Airdrop.airdropChancePercent.lighthouse = Config.Loot.Airdrops.Lighthouse_air;
			Airdrop.airdropChancePercent.bigmap = Config.Loot.Airdrops.Bigmap_air;
			Airdrop.airdropChancePercent.interchange = Config.Loot.Airdrops.Interchange_air;
			*/
		}
		//############## BOTS SECTION ##################
		if (Config.Bots.EnableBots)
		{
			Logger.debug("SVM:Bot section settings enabled")


			Bots.pmc.convertIntoPmcChance.assault.min = Config.Bots.AItoPMC.PMCtoScav;
			Bots.pmc.convertIntoPmcChance.cursedassault.min = Config.Bots.AItoPMC.PMCtoCursedScav;
			Bots.pmc.convertIntoPmcChance.pmcbot.min = Config.Bots.AItoPMC.PMCtoRaider;
			Bots.pmc.convertIntoPmcChance.exusec.min = Config.Bots.AItoPMC.ExusectoPMC;
			Bots.pmc.convertIntoPmcChance.marksman = [];
			Bots.pmc.convertIntoPmcChance.marksman.min = Config.Bots.AItoPMC.SnipertoPMC;

			Bots.pmc.convertIntoPmcChance.assault.max = Config.Bots.AItoPMC.PMCtoScav;
			Bots.pmc.convertIntoPmcChance.cursedassault.max = Config.Bots.AItoPMC.PMCtoCursedScav;
			Bots.pmc.convertIntoPmcChance.pmcbot.max = Config.Bots.AItoPMC.PMCtoRaider;
			Bots.pmc.convertIntoPmcChance.exusec.max = Config.Bots.AItoPMC.ExusectoPMC;
			Bots.pmc.convertIntoPmcChance.marksman.max = Config.Bots.AItoPMC.SnipertoPMC;
			Bots.pmc.isUsec = Config.Bots.PMCRatio;
			Bots.maxBotCap = Config.Bots.BotSpawn.GlobalATO;
			Bots.pmc.chanceSameSideIsHostilePercent = Config.Bots.HostilePMC;
			locations["bigmap"].base.MaxBotPerZone = Config.Bots.BotSpawn.CustomsSPZ;
			locations["factory4_day"].base.MaxBotPerZone = Config.Bots.BotSpawn.FactoryNightSPZ;
			locations["factory4_night"].base.MaxBotPerZone = Config.Bots.BotSpawn.FactoryDaySPZ;
			locations["interchange"].base.MaxBotPerZone = Config.Bots.BotSpawn.InterchangeSPZ;
			locations["laboratory"].base.MaxBotPerZone = Config.Bots.BotSpawn.LaboratorySPZ;
			locations["shoreline"].base.MaxBotPerZone = Config.Bots.BotSpawn.ShorelineSPZ;
			locations["woods"].base.MaxBotPerZone = Config.Bots.BotSpawn.WoodsSPZ;
			locations["rezervbase"].base.MaxBotPerZone = Config.Bots.BotSpawn.ReserveSPZ;
			locations["lighthouse"].base.MaxBotPerZone = Config.Bots.BotSpawn.LighthouseSPZ;
		    const BotWepDur	= Config.Bots.BotWeaponDurability;
			const BotWepMinID = [BotWepDur.WeaponScavMin, BotWepDur.WeaponMarksmanMin, BotWepDur.WeaponRaiderMin, BotWepDur.WeaponRogueMin, BotWepDur.WeaponPMCMin, BotWepDur.WeaponBossMin, BotWepDur.WeaponFollowerMin];
			const BotWepMaxID = [BotWepDur.WeaponScavMax, BotWepDur.WeaponMarksmanMax, BotWepDur.WeaponRaiderMax, BotWepDur.WeaponRogueMax, BotWepDur.WeaponPMCMax, BotWepDur.WeaponBossMax, BotWepDur.WeaponFollowerMax];
			const BotWepTypeID = ["assault","marksman","pmcbot","exusec","pmc","boss","follower"]
			for ( let durab in BotWepTypeID)
			{
			Bots.durability[BotWepTypeID[durab]].weapon.lowestMax = BotWepMinID[durab]
			Bots.durability[BotWepTypeID[durab]].weapon.highestMax = BotWepMaxID[durab]
				switch (BotWepTypeID[durab])
				{
					case "assault":
						Bots.durability["cursedassault"].weapon.lowestMax = BotWepMinID[durab]
						Bots.durability["cursedassault"].weapon.highestMax = BotWepMaxID[durab]
						break;
					case "boss":
						Bots.durability["sectantpriest"].weapon.lowestMax = BotWepMinID[durab];
						Bots.durability["sectantpriest"].weapon.highestMax = BotWepMaxID[durab];
						break;
					case "follower":
						Bots.durability["sectantwarrior"].weapon.lowestMax = BotWepMinID[durab];
						Bots.durability["sectantwarrior"].weapon.highestMax = BotWepMaxID[durab];
						break;
				}
			}
		}
		//############## DEPRECATED SECTION #########
		if (Config.Deprecated.EnableDeprecated) //Still dunno should i bonk it or nah.
		{
			Bots.presetBatch.assault = Config.Deprecated.BotLoadouts.Assault;
			Bots.presetBatch.marksman = Config.Deprecated.BotLoadouts.Marksman;
			Bots.presetBatch.pmcBot = Config.Deprecated.BotLoadouts.PMCbot;
			Bots.presetBatch.bossBully = Config.Deprecated.BotLoadouts.Reshala;
			Bots.presetBatch.bossGluhar = Config.Deprecated.BotLoadouts.Glukhar;
			Bots.presetBatch.bossKilla = Config.Deprecated.BotLoadouts.Killa;
			Bots.presetBatch.bossKojaniy = Config.Deprecated.BotLoadouts.Shturman;
			Bots.presetBatch.bossSanitar = Config.Deprecated.BotLoadouts.Sanitar;
			Bots.presetBatch.followerBully = Config.Deprecated.BotLoadouts.Zavodskoy;
			Bots.presetBatch.followerGluharAssault = Config.Deprecated.BotLoadouts.Glukhar_assault;
			Bots.presetBatch.followerGluharScout = Config.Deprecated.BotLoadouts.Glukhar_scout;
			Bots.presetBatch.followerGluharSecurity = Config.Deprecated.BotLoadouts.Glukhar_security;
			Bots.presetBatch.followerGluharSnipe = Config.Deprecated.BotLoadouts.Glukhar_snipe;
			Bots.presetBatch.followerKojaniy = Config.Deprecated.BotLoadouts.Shturman_followers;
			Bots.presetBatch.followerSanitar = Config.Deprecated.BotLoadouts.Sanitar_followers;
			Bots.presetBatch.test = Config.Deprecated.BotLoadouts.Test;
			Bots.presetBatch.followerTest = Config.Deprecated.BotLoadouts.Test;
			Bots.presetBatch.bossTest = Config.Deprecated.BotLoadouts.Bosstest;
			Bots.presetBatch.assaultGroup = Config.Deprecated.BotLoadouts.Assault_group;
			Bots.presetBatch.playerScav = Config.Deprecated.BotLoadouts.PlayerScav;
			Bots.presetBatch.sectantWarrior = Config.Deprecated.BotLoadouts.Cultists;
			Bots.presetBatch.sectantPriest = Config.Deprecated.BotLoadouts.Cultist_priest;
		}
			if (Config.Deprecated.EnableBarterStack)
				{
				for (const id in items)
				{
					let base = items[id]
					switch (base._parent)
					{
						case "57864ee62459775490116fc1":
							// Battery
							EditSimpleItemData(id, "StackMaxSize", Config.Deprecated.StackValues.Battery)
							break;
						case "57864ada245977548638de91":
							//Building materials
							EditSimpleItemData(id, "StackMaxSize", Config.Deprecated.StackValues.Buildmats)
							break;
						case "57864a66245977548f04a81f":
							//Electronics
							EditSimpleItemData(id, "StackMaxSize", Config.Deprecated.StackValues.Electronics)
							break;
						case "57864c322459775490116fbf":
							//Household goods
							EditSimpleItemData(id, "StackMaxSize", Config.Deprecated.StackValues.Householdgoods)
							break;
						case "57864a3d24597754843f8721":
							// Valuables
							EditSimpleItemData(id, "StackMaxSize", Config.Deprecated.StackValues.Jewelry)
							break;
						case "57864c8c245977548867e7f1":
							//Medical supplies
							EditSimpleItemData(id, "StackMaxSize", Config.Deprecated.StackValues.Medsupplies)
							break;
						case "57864e4c24597754843f8723":
							//Flammable
							EditSimpleItemData(id, "StackMaxSize", Config.Deprecated.StackValues.Fuel)
							break;
						case "57864bb7245977548b3b66c2":
							//Tools
							EditSimpleItemData(id, "StackMaxSize", Config.Deprecated.StackValues.Tools)
							break;
						case "590c745b86f7743cc433c5f2":
							//Other
							if(id !== "59f32bb586f774757e1e8442" && id !== "59f32c3b86f77472a31742f0")
							{
							EditSimpleItemData(id, "StackMaxSize", Config.Deprecated.StackValues.Other)
							}
							break;
					}
				}
				}
		//############## INSURANCE SECTION #############
		if (Config.Insurance.EnableInsurance)
		{
			Logger.debug("SVM:Insurance settings enabled")
			Insurance.insuranceMultiplier["54cb50c76803fa8b248b4571"] = Config.Insurance.InsuranceMultPrapor;
			Insurance.insuranceMultiplier["54cb57776803fa99248b456e"] = Config.Insurance.InsuranceMultTherapist;
			Insurance.returnChancePercent["54cb50c76803fa8b248b4571"] = Config.Insurance.ReturnChancePrapor;
			Insurance.returnChancePercent["54cb57776803fa99248b456e"] = Config.Insurance.ReturnChanceTherapist;
			globals.Insurance.MaxStorageTimeInHour = Config.Insurance.InsuranceStorageTime;						
			traders["54cb50c76803fa8b248b4571"].base.insurance.min_return_hour = Config.Insurance.InsuranceTime.Prapor_Min;
			traders["54cb50c76803fa8b248b4571"].base.insurance.max_return_hour = Config.Insurance.InsuranceTime.Prapor_Max;
			traders["54cb57776803fa99248b456e"].base.insurance.min_return_hour = Config.Insurance.InsuranceTime.Therapist_Min;
			traders["54cb57776803fa99248b456e"].base.insurance.max_return_hour = Config.Insurance.InsuranceTime.Therapist_Max;
		}
		//############## CSM SECTION ###################
		if (Config.CSM.EnableCSM)
		{
			if (Config.CSM.CustomPocket)
			{
				const JsonUtil = container.resolve("JsonUtil");
				let CustomPocketItem = JsonUtil.clone(items["627a4e6b255f7527fb05a0f6"])
				let PocketSize = Config.CSM.Pockets
				CustomPocketItem._id = "CustomPocket"
				CustomPocketItem._props.Grids[0]._id = "SVMPocket1"
				CustomPocketItem._props.Grids[0]._parent = "CustomPocket"
				CustomPocketItem._props.Grids[0]._props.cellsH = PocketSize.FirstH
				CustomPocketItem._props.Grids[0]._props.cellsV = PocketSize.FirstV
				CustomPocketItem._props.Grids[1]._id = "SVMPocket2"
				CustomPocketItem._props.Grids[1]._parent = "CustomPocket"
				CustomPocketItem._props.Grids[1]._props.cellsH = PocketSize.SecondH
				CustomPocketItem._props.Grids[1]._props.cellsV = PocketSize.SecondV
				CustomPocketItem._props.Grids[2]._id = "SVMPocket3"
				CustomPocketItem._props.Grids[2]._parent = "CustomPocket"
				CustomPocketItem._props.Grids[2]._props.cellsH = PocketSize.ThirdH
				CustomPocketItem._props.Grids[2]._props.cellsV = PocketSize.ThirdV
				CustomPocketItem._props.Grids[3]._id = "SVMPocket4"
				CustomPocketItem._props.Grids[3]._parent = "CustomPocket"
				CustomPocketItem._props.Grids[3]._props.cellsH = PocketSize.FourthH
				CustomPocketItem._props.Grids[3]._props.cellsV = PocketSize.FourthV
				CustomPocketItem._props.Slots[0]._id = "SVMSPEC1"
				CustomPocketItem._props.Slots[1]._id = "SVMSPEC2"
				CustomPocketItem._props.Slots[2]._id = "SVMSPEC3"
				CustomPocketItem._props.Slots[0]._parent = "CustomPocket"
				CustomPocketItem._props.Slots[1]._parent = "CustomPocket"
				CustomPocketItem._props.Slots[2]._parent = "CustomPocket"
				//CustomPocketItem._props.Slots[2] = undefined;
				//CustomPocketItem._props.Slots.splice(1,2);
				if (PocketSize.FourthH == 0 || PocketSize.FourthV == 0)
				{
					CustomPocketItem._props.Grids.splice(3,1);
				}
				if (PocketSize.ThirdH == 0 || PocketSize.ThirdV == 0)
				{
					CustomPocketItem._props.Grids.splice(2,1);
				}
				if (PocketSize.SecondH == 0 || PocketSize.SecondV == 0)
				{
					CustomPocketItem._props.Grids.splice(1,1);
				}
				if (PocketSize.FirstH == 0 || PocketSize.FirstV == 0)
				{
					CustomPocketItem._props.Grids.splice(0,1);
				}

				switch (Config.CSM.Pockets.SpecSlots)
				{
					case 0:
						CustomPocketItem._props.Slots.splice(0,3);
						break;
				case 1:
					CustomPocketItem._props.Slots.splice(1,2);
					break;
				case 2:
					CustomPocketItem._props.Slots.splice(2,1);
					break;
				case 3:
					break;
				}
				items["CustomPocket"] = CustomPocketItem;
			}

			Logger.debug("SVM:CSM settings enabled")
			const Cases = Config.CSM.Cases
			const SecCon = Config.CSM.SecureContainers
			const SecConID = ["544a11ac4bdc2d470e8b456a", 
										  "5c093ca986f7740a1867ab12", 
										  "5857a8b324597729ab0a0e7d", 
										  "59db794186f77448bc595262", 
										  "5857a8bc2459772bad15db29"
			]
			const CasesID = ["59fb016586f7746d0d4b423a", 
										"5783c43d2459774bbe137486", 
										"60b0f6c058e0b0481a09ad11", 
										"5e2af55f86f7746d4159f07c", 
										"59fb042886f7746c5005a7b2", 
										"59fb023c86f7746d0d4b423c", 
										"5b7c710788a4506dec015957", 
										"5aafbde786f774389d0cbc0f", 
										"5c127c4486f7745625356c13", 
										"5c093e3486f77430cb02e593", 
										"5aafbcd986f7745e590fff23", 
										"5c0a840b86f7742ffa4f2482", 
										"5b6d9ce188a4501afc1b2b25", 
										"5d235bb686f77443f4331278", 
										"59fafd4b86f7745ca07e1232", 
										"590c60fc86f77412b13fddcf", 
										"567143bf4bdc2d1a0f8b4567", 
										"5c093db286f7740a1b2617e3", 
										"619cbf7d23893217ec30b689", 
										"619cbf9e0a7c3a1a2731940a",
										"62a09d3bcf4a99369e262447"
			]
			const Vsize = [
				Cases.MoneyCaseVSize,
				Cases.SimpleWalletVSize,
				Cases.WZWalletVSize,
				Cases.GrenadeCaseVSize,
				Cases.ItemsCaseVSize,
				Cases.WeaponCaseVSize,
				Cases.LuckyScavVSize,
				Cases.AmmunitionCaseVSize,
				Cases.MagazineCaseVSize,
				Cases.DogtagCaseVSize,
				Cases.MedicineCaseVSize,
				Cases.ThiccItemsCaseVSize,
				Cases.ThiccWeaponCaseVSize,
				Cases.SiccCaseVSize,
				Cases.KeytoolVSize,
				Cases.DocumentsCaseVSize,
				Cases.PistolCaseVSize,
				Cases.HolodilnickVSize,
				Cases.InjectorCaseVSize,
				Cases.KeycardHolderCaseVSize,
				Cases.GKeychainVSize
			]
			const Hsize = [
				Cases.MoneyCaseHSize,
				Cases.SimpleWalletHSize,
				Cases.WZWalletHSize,
				Cases.GrenadeCaseHSize,
				Cases.ItemsCaseHSize,
				Cases.WeaponCaseHSize,
				Cases.LuckyScavHSize,
				Cases.AmmunitionCaseHSize,
				Cases.MagazineCaseHSize,
				Cases.DogtagCaseHSize,
				Cases.MedicineCaseHSize,
				Cases.ThiccItemsCaseHSize,
				Cases.ThiccWeaponCaseHSize,
				Cases.SiccCaseHSize,
				Cases.KeytoolHSize,
				Cases.DocumentsCaseHSize,
				Cases.PistolCaseHSize,
				Cases.HolodilnickHSize,
				Cases.InjectorCaseHSize,
				Cases.KeycardHolderCaseHSize,
				Cases.GkeychainHSize,

			]
			const SecVsize = [SecCon.AlphaVSize,
				SecCon.KappaVSize,
				SecCon.BetaVSize,
				SecCon.EpsilonVSize,
				SecCon.GammaVSize
			];
			const SecHsize = [SecCon.AlphaHSize,
				SecCon.KappaHSize,
				SecCon.BetaHSize,
				SecCon.EpsilonHSize,
				SecCon.GammaHSize
			];
			const Filts = [
				Cases.MoneyCaseFilter,
				Cases.SimpleWalletFilter,
				Cases.WZWalletFilter,
				Cases.GrenadeCaseFilter,
				Cases.ItemsCaseFilter,
				Cases.WeaponCaseFilter,
				Cases.LuckyScavFilter,
				Cases.AmmunitionCaseFilter,
				Cases.MagazineCaseFilter,
				Cases.DogtagCaseFilter,
				Cases.MedicineCaseFilter,
				Cases.ThiccItemsCaseFilter,
				Cases.ThiccWeaponCaseFilter,
				Cases.SiccCaseFilter,
				Cases.KeytoolFilter,
				Cases.DocumentsCaseFilter,
				Cases.PistolCaseFilter,
				Cases.HolodilnickFilter,
				Cases.InjectorCaseFilter,
				Cases.KeycardHolderCaseFilter,
				Cases.GkeychainFilter
			]
			for (let SecConts in SecConID)
			{
				items[SecConID[SecConts]]._props.Grids[0]._props["cellsV"] = SecVsize[SecConts];
				items[SecConID[SecConts]]._props.Grids[0]._props["cellsH"] = SecHsize[SecConts];
			}
			for (let Case in CasesID)
			{
				items[CasesID[Case]]._props.Grids[0]._props["cellsV"] = Vsize[Case];
				items[CasesID[Case]]._props.Grids[0]._props["cellsH"] = Hsize[Case];
			}
			//Filters
			for (let Filters in Filts)
			{
				if (Filts[Filters]) // To check whether checkmark is true or false
				{
					items[CasesID[Filters]]._props.Grids[0]._props.filters = [];
				}
			}
		// 60c7272c204bc17802313365 карманы 1 на 3
		// 557ffd194bdc2d28148b457f 1 на 4
		// 5af99e9186f7747c447120b8 большие
		}
		//############## ITEMS SECTION ##################
		if (Config.Items.EnableItems)
		{
			Logger.debug("SVM:Items settings enabled")
			//Price Modifier
			for (const item in DB.templates.handbook.Items)
			{
				if (DB.templates.handbook.Items[item].ParentId !== "5b5f78b786f77447ed5636af" && DB.templates.handbook.Items[item].Price != null)
				{
					DB.templates.handbook.Items[item].Price = DB.templates.handbook.Items[item].Price * Config.Items.ItemPriceMult
				}
			}
			//Logger.info(globals)
			globals.BaseUnloadTime = globals.BaseUnloadTime * Config.Items.AmmoLoadSpeed;
			globals.BaseLoadTime = globals.BaseLoadTime * Config.Items.AmmoLoadSpeed;
			for (const id in items)
			{
				let base = items[id] //I'm consistent af, need to either ditch such usage or switch to it, smh.
				//Load-Unload
				if(base._type == "Item" &&  base._props.DiscardLimit !== undefined && Config.Items.RaidDrop)
				{
					EditSimpleItemData(id, "DiscardLimit", -1);
				}
				if (base._props.AllowOverheat !== undefined && Config.Items.WeaponHeatOff)
				{
					EditSimpleItemData(id, "AllowOverheat", false);
				}
				/*if (base._parent == "5448bc234bdc2d3c308b4569" && (Config.Items.AmmoLoadSpeed !== 0 || Config.Items.AmmoLoadSpeed !== undefined))
				{
					EditSimpleItemData(id, "LoadUnloadModifier",
						(-Config.Items.AmmoLoadSpeed));
				}*/
				//Malfunction 
				if ((base._parent == "5447b5cf4bdc2d65278b4567" ||base._parent == "5447b6254bdc2dc3278b4568" || items[id]._parent == "5447b5f14bdc2d61278b4567" || items[id]._parent == "5447bed64bdc2d97278b4568" || items[id]._parent == "5447b6094bdc2dc3278b4567" || items[id]._parent == "5447b5e04bdc2d62278b4567" || items[id]._parent == "5447b6194bdc2d67278b4567") && items[id]._props.BaseMalfunctionChance !== undefined)
				{
					EditSimpleItemData(id,"BaseMalfunctionChance",parseFloat(base._props.BaseMalfunctionChance * Config.Items.MalfunctChanceMult).toFixed(4));
				}
				if (base._parent === "5448bc234bdc2d3c308b4569" && base._props.MalfunctionChance !== undefined)
				{
					EditSimpleItemData(id,"MalfunctionChance", parseFloat(base._props.MalfunctionChance* Config.Items.MalfunctChanceMult).toFixed(3));
				}
				//Misfire - WIP
				if (base._parent === "5485a8684bdc2da71d8b4567" && base._props.MisfireChance !== undefined)
				{
					EditSimpleItemData(id,"MisfireChance", parseFloat(base._props.MisfireChance * Config.Items.MisfireChance).toFixed(3));
				}
				// BallisticCoeficient - WIP
				if (base._parent === "5485a8684bdc2da71d8b4567" && base._props.BallisticCoeficient !== undefined)
				{
					EditSimpleItemData(id,"BallisticCoeficient", parseFloat(base._props.BallisticCoeficient * Config.Items.BallisticCoefMult).toFixed(4));
				}
				//Examine all items
				if (Config.Items.AllExaminedItems)
				{
					EditSimpleItemData(id, "ExaminedByDefault", true);
				}
				//Change the weight - finally got rid of variables i had to force, i also think i could simplify that "if".
				if (base._type !== "Node" && base._type !== undefined && (base.parent !== "557596e64bdc2dc2118b4571" || base._parent !== "55d720f24bdc2d88028b456d"))
				{
					EditSimpleItemData(id, "Weight",
						parseFloat(Config.Items.WeightChanger * base._props.Weight).toFixed(3));
				}
				if (Config.Items.NoGearPenalty)
				{
					if (base._props.mousePenalty)
					{
						EditSimpleItemData(id, "mousePenalty", 0)
					}
					if (base._props.weaponErgonomicPenalty)
					{
						EditSimpleItemData(id, "weaponErgonomicPenalty", 0)
					}
					if (base._props.speedPenaltyPercent)
					{
						EditSimpleItemData(id, "speedPenaltyPercent", 0)
					}
				}
				//if (base._name.includes("patron"))// TODO: Add 357. because revolver.
				if (base._parent.includes("5485a8684bdc2da71d8b4567"))
				{
					let str = base._name.split("_", 2)
					if (str[1] == "9x19" || str[1] == "9x18pm" || str[1] == "9x21" || str[1] == "762x25tt" || str[1] == "46x30" || str[1] == "57x28" || str[1] == "1143x23" || str[1] == "9x33r")
					{
						EditSimpleItemData(id, "StackMaxSize", Config.Items.AmmoStacks.PistolRound)
					}
					if (str[1] == "12x70" || str[1] == "20x70" || str[1] == "23x75")
					{
						EditSimpleItemData(id, "StackMaxSize", Config.Items.AmmoStacks.ShotgunRound)
					}
					if (str[1] == "762x39" || str[1] == "545x39" || str[1] == "556x45" || str[1] == "9x39" || str[1] == "366" || str[1] == "762x35" || str[1] == "300blk" || str[1] == "ATL15")
					{
						EditSimpleItemData(id, "StackMaxSize", Config.Items.AmmoStacks.RifleRound)
					}
					if (str[1] == "762x51" || str[1] == "762х54R" || str[1] == "762x54r" || str[1] == "86x70" || str[1] == "127x55")
					{
						EditSimpleItemData(id, "StackMaxSize", Config.Items.AmmoStacks.MarksmanRound)
					}
					//KMC
					if (str[2] == "10MM" || str[2] == "40SW" || str[2] == "357SIG" || str[2] == "9MM" || str[2] == "45ACP" || str[2] == "50AE" || str[2] == "380AUTO")
					{
						EditSimpleItemData(id, "StackMaxSize", Config.Items.AmmoStacks.PistolRound)
					}
					if (str[2] == "GRENDEL" || str[2] == "50WLF")
					{
						EditSimpleItemData(id, "StackMaxSize", Config.Items.AmmoStacks.RifleRound)
					}
					if (str[2] == "BMG" || str[2] == "277")
					{
						EditSimpleItemData(id, "StackMaxSize", Config.Items.AmmoStacks.MarksmanRound)
					}
					if (str[2] == "KURZ")
					{
						EditSimpleItemData(id, "StackMaxSize", Config.Items.AmmoStacks.RifleRound)
					}
				}
				//Change money stacks
				if (base._parent == "543be5dd4bdc2deb348b4569" && Config.Items.CashStack !== 500000) //Need to rebuild all of this.
				{
					EditSimpleItemData(id, "StackMaxSize", Config.Items.CashStack);
				}
				//Allow armored rigs with armors
				if (Config.Items.EquipRigsWithArmors && base._props.BlocksArmorVest)
				{
					EditSimpleItemData(id, "BlocksArmorVest", false);
				}
				//Remove filters
				if (Config.Items.RemoveSecureContainerFilters && base._parent == "5448bf274bdc2dfc2f8b456a" && base._props.Grids[0]._props.filters !== undefined)
				{
					base._props.Grids[0]._props.filters = [];
					//base._props.Grids[0]._props.filters[0].Filter = [];
					//base._props.Grids[0]._props.filters[0].ExcludedFilter = [];
				}
				if (Config.Items.RemoveBackpacksRestrictions && base._parent == "5448e53e4bdc2d60728b4567" && base._props.Grids[0]._props.filters !== undefined)
				{
					base._props.Grids[0]._props.filters = [];
				}
				//Change items experience gain
				if (base._props.LootExperience !== undefined)
				{
					let calculation = Math.round(base._props.LootExperience * Config.Items.LootExp);
					EditSimpleItemData(id, "LootExperience", calculation);
				}
				if (base._props.ExamineExperience !== undefined)
				{
					let calculation = Math.round(base._props.ExamineExperience * Config.Items.ExamineExp);
					EditSimpleItemData(id, "ExamineExperience", calculation);
				}
				//Remove the keys usage
				if (Config.Items.RemoveKeysUsageNumber && (base._parent == "5c99f98d86f7745c314214b3" || base._parent == "5c164d2286f774194c5e69fa"))
				{
					base._props.MaximumNumberOfUsage = 0
				}
				//Change weapons parts moddability
				if (Config.Items.InRaidModdable && base._props.RaidModdable)
				{
					EditSimpleItemData(id, "RaidModdable", true);
					if (base._props.ToolModdable)
					{
						EditSimpleItemData(id, "ToolModdable", true);
					}
					if (base._props.Slots)
					{
						for (let z in base._props.Slots)
						{
							if (base._props.Slots[z]._required !== "false")
							{
								base._props.Slots[z]._required = false;
							}
						}
					}
				}
			}
			if (Config.Items.SMGToHolster)
			{
			items["55d7217a4bdc2d86028b456d"]._props.Slots[2]._props.filters[0].Filter.push("5447b5e04bdc2d62278b4567");
			}
			if (Config.Items.PistolToMain)
			{
			items["55d7217a4bdc2d86028b456d"]._props.Slots[0]._props.filters[0].Filter.push("5447b5cf4bdc2d65278b4567","617f1ef5e8b54b0998387733");
			items["55d7217a4bdc2d86028b456d"]._props.Slots[1]._props.filters[0].Filter.push("5447b5cf4bdc2d65278b4567","617f1ef5e8b54b0998387733");
			}
			if (Config.Items.RemoveRaidRestr)
			{
				globals.RestrictionsInRaid = []
			}
			if (Config.Items.IDChanger)
			{
				//Edit item properties, i know it looks stupid, but hey - it works and i like it.
				//Second revision, i've created a monster. now you can literally alter any field/filter/grid with it.
				if (Config.ItemList !== {})
				{
					try
					{
						for (let k in Config.ItemList)
						{
							let fin = Config.ItemList[k].split(":", 6)
							if (fin[3] == null)
							{
								Logger.info("ID: " + fin[0] + " Property: " + fin[1] + " Value: " + fin[2])
								if (fin[2].includes(",") || fin[2].includes("["))
								{
									let test = fin[2].substring(1, fin[2].length - 1)
									let arrayfin = test.split(",")
									EditSimpleItemData(fin[0], fin[1], arrayfin)
								}
								else
								{
									EditSimpleItemData(fin[0], fin[1], fin[2])
								} //For basic items properties
							}
							else if (fin[4] == null)
							{
								Logger.info("ID: " + fin[0] + " Structure: " + fin[1] + " Property: " + fin[2] + " Value: " + fin[3])
								if (fin[3].includes(",") || fin[3].includes("["))
								{
									let test = fin[3].substring(1, fin[3].length - 1)
									let arrayfin = test.split(",")
									EditAdvancedItemData(fin[0], fin[1], fin[2], arrayfin)
								}
								else
								{
								EditAdvancedItemData(fin[0], fin[1], fin[2], fin[3])
								}
							}
							else if (fin[5] == null) //Mags and their sizes
							{
								Logger.info("ID: " + fin[0] + " Structure: " + fin[1] + " Array: " + fin[2] + " Property: " + fin[3] + " Value: " + fin[4])
								if (fin[4].includes(",") || fin[4].includes("["))
								{
									let test = fin[4].substring(1, fin[4].length - 1)
									let arrayfin = test.split(",")
									EditEnchancedtemData(fin[0], fin[1], fin[2], fin[3], arrayfin)
								}
								else
								{
								EditEnchancedtemData(fin[0], fin[1], fin[2], fin[3], fin[4])
								}
							}
							else
							{
								Logger.info("ID: " + fin[0] + " Ext.Structure: " + fin[1] + " Array: " + fin[2] + " Int.Structure: " + fin[3] + " Property: " + fin[4] + " Value: " + fin[5])
								if (fin[4].includes(",") || fin[4].includes("["))
								{
									let test = fin[4].substring(1, fin[4].length - 1)
									let arrayfin = test.split(",")
									EditComplicatedItemData(fin[0], fin[1], fin[2], fin[3], fin[4], arrayfin)
								}
								else
								{
								EditComplicatedItemData(fin[0], fin[1], fin[2], fin[3], fin[4], fin[5]) //Stupidly long one for Backpacks, Initial _props after ID, Grids, number of grid, another selectable _props, and only then values.
								}
							}
						}
						Logger.success("SVM: Custom properties successfully loaded")
					}
					catch (e)
					{
						Logger.error("SVM: Custom properties failed to load, error of the code:" + e)
					}
				}
			}
		}
		//############## PLAYER SECTION #################
		if (Config.Player.EnablePlayer)
		{
			Logger.debug("SVM:Player settings enabled")
			//Skill box
			globals.SkillsSettings.SkillProgressRate = Config.Player.SkillProgMult;
			globals.SkillsSettings.WeaponSkillProgressRate = Config.Player.WeaponSkillMult;
			//health after raid box
			Health.healthMultipliers.death = Config.Player.DiedHealth.Health_death;
			Health.healthMultipliers.blacked = Config.Player.DiedHealth.Health_blacked;
			Health.save.health = Config.Player.DiedHealth.Savehealth;
			Health.save.effects = Config.Player.DiedHealth.Saveeffects;
			
			// skill eff box
			globals.SkillMinEffectiveness = Config.Player.Skills.SkillMinEffect;
			globals.SkillFatiguePerPoint = Config.Player.Skills.SkillFatiguePerPoint;
			globals.SkillFreshEffectiveness = Config.Player.Skills.SkillFreshEffect;
			globals.SkillFreshPoints = Config.Player.Skills.SkillFPoints;
			globals.SkillPointsBeforeFatigue = Config.Player.Skills.SkillPointsBeforeFatigue;
			globals.SkillFatigueReset = Config.Player.Skills.SkillFatigueReset;
			//Remove fall damages
			if (Config.Player.FallDamage)
			{
				Logger.debug("SVM: Icarus wings granted");
				globals.Health.Falling.SafeHeight = 200
				globals.Health.Falling.DamagePerMeter = 0
			}
			//Change stamina (unlimited or no)
			if (Config.Player.MaxStamina !== 100 && !Config.Player.UnlimitedStamina)
			{
				Logger.debug("SVM: Custom maximum stamina activated");
				globals.Stamina.Capacity = Config.Player.MaxStamina;
			}
			else if (Config.Player.UnlimitedStamina)
			{
				Logger.debug("SVM: Unlimited stamina - granted");
				globals.Stamina.Capacity = 500;
				globals.Stamina.BaseRestorationRate = 500;
				globals.Stamina.StaminaExhaustionCausesJiggle = false;
				globals.Stamina.StaminaExhaustionStartsBreathSound = false;
				globals.Stamina.StaminaExhaustionRocksCamera = false;
				globals.Stamina.SprintDrainRate = 0;
				globals.Stamina.JumpConsumption = 0;
				globals.Stamina.AimDrainRate = 0;
				globals.Stamina.SitToStandConsumption = 0;
			}
			globals.SkillsSettings.SearchAction = 33
			//  "FindAction": 0.166,
			//	"SearchAction": 0.33
			if (Config.Player.InstantSearch)
			{
				//globals.SkillsSettings.
			}
			globals.Health.Effects.Existence.HydrationLoopTime = (globals.Health.Effects.Existence.HydrationLoopTime / Config.Player.HydrationLoss)
			globals.Health.Effects.Existence.EnergyLoopTime = (globals.Health.Effects.Existence.EnergyLoopTime / Config.Player.EnergyLoss)
			globals.Health.Effects.Existence.DestroyedStomachEnergyTimeFactor = Config.Player.BlackStomach;
			globals.Health.Effects.Existence.DestroyedStomachHydrationTimeFactor = Config.Player.BlackStomach;
		}
		//############## HIDEOUT SECTION ################
		if (Config.Hideout.EnableHideout)
		{
			Logger.debug("SVM:Hideout settings enabled")
			//Change hideout fuel consumption .toFixed(3)
			hideout.settings.generatorFuelFlowRate = Config.Hideout.FuelConsumptionRate;
			hideout.settings.generatorSpeedWithoutFuel = Config.Hideout.NoFuelMult;
			//hideoutC.fuelDrainRateMultipler = Config.Hideout.FuelConsumptionRate;
			hideout.settings.airFilterUnitFlowRate = Config.Hideout.AirFilterRate;
			hideout.settings.gpuBoostRate = Config.Hideout.GPUBoostRate;
			//hideout.productions
			
			//Enable hideout fast constructions
			for (const data in hideout.areas)
			{
				let areaData = hideout.areas[data]
				for (const i in areaData.stages)
				{
					if (areaData.stages[i].constructionTime > 0)
					{
						areaData.stages[i].constructionTime = parseInt(areaData.stages[i].constructionTime * Config.Hideout.HideoutConstMult)
					}
				}
			}
			//Enable fast hideout production
			for (const data in hideout.production)
			{
				let productionData = hideout.production[data];
				//Logger.info(productionData, "red")
				
					if (productionData._id == "5d5589c1f934db045e6c5492")
					{
						productionData.productionTime = Config.Hideout.WaterFilterTime
						productionData.requirements[1].resource = Config.Hideout.WaterFilterRate
					}
					if (productionData._id == "5d5c205bd582a50d042a3c0e")
					{
						productionData.productionLimitCount = Config.Hideout.MaxBitcoins;
						productionData.productionTime = Config.Hideout.BitcoinTime;
					}
				if (!productionData.continuous && productionData.productionTime >= 10)
				{
					productionData.productionTime = parseInt(productionData.productionTime * Config.Hideout.HideoutProdMult)
				}
			}
			//Scav cases modifications
				for (const scav in hideout.scavcase)
				{
					let caseData = hideout.scavcase[scav];
					if (caseData.ProductionTime >= 10)
					{
						caseData.ProductionTime = parseInt(caseData.ProductionTime * Config.Hideout.ScavCaseTime);
					}
				}
				for (const scase in hideout.scavcase)
				{
					let caseData = hideout.scavcase[scase];
					if (caseData.Requirements[0].templateId == "5449016a4bdc2d6f028b456f" || caseData.Requirements[0].templateId == "5696686a4bdc2da3298b456a" || caseData.Requirements[0].templateId == "569668774bdc2da2298b4568")
					{
						caseData.Requirements[0].count = parseInt(caseData.Requirements[0].count * Config.Hideout.ScavCasePrice);
					}
				}
			//Remove construction requirements
			if (Config.Hideout.RemoveConstructionsRequirements)
			{
				for (const data in hideout.areas)
				{
					let areaData = hideout.areas[data]
					for (const i in areaData.stages)
					{
						if (areaData.stages[i].requirements !== undefined)
						{
							areaData.stages[i].requirements = [];
						}
					}
				}
			}
		}
		//############## RAIDS SECTION ###################
		if (Config.Raids.EnableRaids)
		{
			Logger.debug("SVM:Raids settings enabled")
			//############## WEATHER SECTION ##################
			WeatherValues.acceleration = Config.Raids.Timeacceleration;
			WeatherValues.weather.clouds.min = Config.Raids.Weather.Clouds_min;
			WeatherValues.weather.clouds.max = Config.Raids.Weather.Clouds_max;
			WeatherValues.weather.windSpeed.min = Config.Raids.Weather.Windspeed_min;
			WeatherValues.weather.windSpeed.max = Config.Raids.Weather.Windspeed_max;
			WeatherValues.weather.windDirection.min = Config.Raids.Weather.Winddirection_min;
			WeatherValues.weather.windDirection.max = Config.Raids.Weather.Winddirection_max;
			WeatherValues.weather.windGustiness.min = Config.Raids.Weather.Windgustiness_min;
			WeatherValues.weather.windGustiness.max = Config.Raids.Weather.Windgustiness_max;
			WeatherValues.weather.rain.min = Config.Raids.Weather.Rain_min;
			WeatherValues.weather.rain.max = Config.Raids.Weather.Rain_max;
			WeatherValues.weather.rainIntensity.min = Config.Raids.Weather.Rainintensity_min;
			WeatherValues.weather.rainIntensity.max = Config.Raids.Weather.Rainintensity_max;
			WeatherValues.weather.fog.min = Config.Raids.Weather.Fog_min;
			WeatherValues.weather.fog.max = Config.Raids.Weather.Fog_max;
			WeatherValues.weather.temp.min = Config.Raids.Weather.Temp_min;
			WeatherValues.weather.temp.max = Config.Raids.Weather.Temp_max;
			WeatherValues.weather.pressure.min = Config.Raids.Weather.Pressure_min;
			WeatherValues.weather.pressure.max = Config.Raids.Weather.Pressure_max;
			//############## END OF RAID SECTION ############## 
			globals.exp.match_end.runnerMult = Config.Raids.RaidMult.Runner
			globals.exp.match_end.miaMult = Config.Raids.RaidMult.MIA
			globals.exp.match_end.survivedMult = Config.Raids.RaidMult.Survived
			globals.exp.match_end.killedMult = Config.Raids.RaidMult.Killed
			//############## INRAID SECTION ##################
			Inraid.MIAOnRaidEnd = Config.Raids.RaidStartup.MIAEndofRaid;
			Inraid.raidMenuSettings.aiAmount = Config.Raids.RaidStartup.AIAmount;
			Inraid.raidMenuSettings.aiDifficulty = Config.Raids.RaidStartup.AIDiffculty;
			Inraid.raidMenuSettings.bossEnabled = Config.Raids.RaidStartup.EnableBosses;
			Inraid.raidMenuSettings.scavWars = Config.Raids.RaidStartup.ScavWars;
			Inraid.raidMenuSettings.taggedAndCursed = Config.Raids.RaidStartup.TaggedAndCursed;
			Inraid.save.loot = Config.Raids.RaidStartup.SaveLoot;
			Inraid.save.durability = Config.Raids.RaidStartup.SaveDurability;
			globals.TimeBeforeDeployLocal = Config.Raids.RaidStartup.TimeBeforeDeployLocal
			//Scav Timer
			if (Config.Raids.NoRunThrough)
			{
				globals.exp.match_end.survived_exp_requirement = 0;
				globals.exp.match_end.survived_seconds_requirement = 0;
			}
			if (Config.Raids.SCAVTimer)
			{
				globals.SavagePlayCooldown = 1;
			}
			DB.locations["laboratory"].base.Insurance = Config.Raids.LabInsurance;
			//Remove labs entry keycard
			if (Config.Raids.Removelabkey)
			{
				Logger.debug("SVM: No key for lab activated");
				locations["laboratory"].base.AccessKeys = []
			}
			//Remove extracts restrictions
			if (Config.Raids.NoExtractRestric)
			{
				Logger.debug("SVM: Extractions requirements removed");
				for (let i in locations)
				{
					if (i !== "base")
					{
						for (let x in locations[i].base.exits)
						{
							if (locations[i].base.exits[x].Name !== "EXFIL_Train" && !locations[i].base.exits[x].Name.includes("lab") || locations[i].base.exits[x].Name === "lab_Vent")
							{
								if (locations[i].base.exits[x].PassageRequirement !== "None")
								{
									locations[i].base.exits[x].PassageRequirement = "None";
								}
								if (locations[i].base.exits[x].ExfiltrationType !== "Individual")
								{
									locations[i].base.exits[x].ExfiltrationType = "Individual";
								}
								if (locations[i].base.exits[x].Id !== '')
								{
									locations[i].base.exits[x].Id = '';
								}
								if (locations[i].base.exits[x].Count !== 0)
								{
									locations[i].base.exits[x].Count = 0;
								}
								if (locations[i].base.exits[x].RequirementTip !== '')
								{
									locations[i].base.exits[x].RequirementTip = '';
								}
								if (locations[i].base.exits[x].RequiredSlot)
								{
									delete locations[i].base.exits[x].RequiredSlot;
								}
							}
						}
					}
				}
			}
			//Make all extractions available to extract
			if (Config.Raids.AllExtractionsAvailable)
			{
				Logger.debug("SVM: Every chance based extract is always available");
				for (let i in locations)
				{
					if (i !== "base")
					{
						for (let x in locations[i].base.exits)
						{
							if (locations[i].base.exits[x].Name !== "EXFIL_Train" && locations[i].base.exits[x].Chance !== 100)
							{
								locations[i].base.exits[x].Chance = 100;
							}
						}
					}
				}
			}
			//Extend raids to 4 hours
			if (Config.Raids.ExtendedRaid)
			{
				Logger.debug("SVM: Extended Raid activated");
				for (let map in locations)
				{
					if (map !== "base")
					{
						locations[map].base.exit_access_time = 240
						locations[map].base.EscapeTimeLimit = 240
					}
				}
			}
			//Make all extractions of the map available regardless of the infill
			if (Config.Raids.ExtendedExtracts)
			{
				Logger.debug("SVM: All extractions of the map available regardless of the infiltration");
				for (let map in locations)
				{
					switch (map)
					{
						case "base":
							break;
						case "bigmap":
							for (const extract in locations[map].base.exits)
							{
								locations[map].base.exits[extract].EntryPoints = "Customs,Boiler Tanks"
							}
							break;
						case "interchange":
							for (const extract in locations[map].base.exits)
							{
								locations[map].base.exits[extract].EntryPoints = "MallSE,MallNW"
							}
							break;
						case "shoreline":
							for (const extract in locations[map].base.exits)
							{
								locations[map].base.exits[extract].EntryPoints = "Village,Riverside"
							}
							break;
						case "woods":
							for (const extract in locations[map].base.exits)
							{
								locations[map].base.exits[extract].EntryPoints = "House,Old Station"
							}
							break;
						case "lighthouse":
							for (const extract in locations[map].base.exits)
							{
								locations[map].base.exits[extract].EntryPoints = "Tunnel,North"
							}
							break;
						default:
							break;
					}
				}
			}
			if (Config.Raids.RaidEvents.Christmas)
			{
				globals.EventType = ["Christmas"];
			}
			if (Config.Raids.RaidEvents.Halloween)
			{
				globals.EventType = ["Halloween", "HalloweenIllumination"];
			}
			if (Config.Raids.RaidEvents.KillaFactory)
			{
				const KillaWave = CreateBoss("bossKilla", 100, "followerBully", 0, locations["factory4_day"].base.OpenZones)
				locations["factory4_day"].base.BossLocationSpawn.push(KillaWave)
				locations["factory4_night"].base.BossLocationSpawn.push(KillaWave)
			}
			if (Config.Raids.RaidEvents.BossesOnReserve)
			{
				let BossWave = CreateBoss("bossKilla", 100, "followerBully", 0, locations["rezervbase"].base.OpenZones)
				locations["rezervbase"].base.BossLocationSpawn.push(BossWave)
				BossWave = CreateBoss("bossBully", 100, "followerBully", 4, locations["rezervbase"].base.OpenZones)
				locations["rezervbase"].base.BossLocationSpawn.push(BossWave)
				BossWave = CreateBoss("bossKojaniy", 100, "followerKojaniy", 2, locations["rezervbase"].base.OpenZones)
				locations["rezervbase"].base.BossLocationSpawn.push(BossWave)
				BossWave = CreateBoss("bossSanitar", 100, "followerSanitar", 2, locations["rezervbase"].base.OpenZones)
				locations["rezervbase"].base.BossLocationSpawn.push(BossWave)
				if (Config.Raids.RaidEvents.IncludeTagilla)
				{
					BossWave = CreateBoss("bossTagilla", 100, "followerBully", 0, locations["rezervbase"].base.OpenZones)
					locations["rezervbase"].base.BossLocationSpawn.push(BossWave)
				}
			}
			if (Config.Raids.RaidEvents.GlukharLabs)
			{
				const Glukhar = {
					"BossName": "bossGluhar",
					"BossChance": 43,
					"BossZone": "ZoneRailStrorage,ZoneRailStrorage,ZoneRailStrorage,ZonePTOR1,ZonePTOR2,ZoneBarrack,ZoneBarrack,ZoneBarrack,ZoneSubStorage",
					"BossPlayer": false,
					"BossDifficult": "normal",
					"BossEscortType": "followerGluharAssault",
					"BossEscortDifficult": "normal",
					"BossEscortAmount": "0",
					"Time": -1,
					"TriggerId": "",
					"TriggerName": "",
					"Supports": [
					{
						"BossEscortType": "followerGluharAssault",
						"BossEscortDifficult": ["normal"],
						"BossEscortAmount": "2"
					},
					{
						"BossEscortType": "followerGluharSecurity",
						"BossEscortDifficult": ["normal"],
						"BossEscortAmount": "2"
					},
					{
						"BossEscortType": "followerGluharScout",
						"BossEscortDifficult": ["normal"],
						"BossEscortAmount": "2"
					}]
				}
				Glukhar.BossZone = locations["laboratory"].base.OpenZones
				locations["laboratory"].base.BossLocationSpawn.push(Glukhar)
			}
			//Make all bosses to 100% spawn - had to move it down to affect funcs above
			if (Config.Raids.IncreaseBossChance)
			{
				Logger.debug("SVM: 100% Boss chance activated");
				for (let i in locations)
				{
					if (i !== "base" && locations[i].base.BossLocationSpawn !== [])
					{
						for (let x in locations[i].base.BossLocationSpawn)
						{
							locations[i].base.BossLocationSpawn[x].BossChance = 100
						}
					}
				}
			}
		}
		//############## TRADERS SECTION #################
		if (Config.Traders.EnableTraders)
		{
			if(Config.Traders.OpArmorRepair)
			{
				for(let armormats in globals.ArmorMaterials)
				{
					globals.ArmorMaterials[armormats].MaxRepairDegradation = 0
					globals.ArmorMaterials[armormats].MinRepairDegradation = 0
					globals.ArmorMaterials[armormats].MaxRepairKitDegradation = 0
					globals.ArmorMaterials[armormats].MinRepairKitDegradation = 0
				}
			}
			if(Config.Traders.OpGunRepair)
			{
				for(let stuff in items)
				{
					if(items[stuff]._props.MaxRepairDegradation !== undefined)
					{
					EditSimpleItemData(stuff, "MinRepairDegradation", 0);
					EditSimpleItemData(stuff, "MaxRepairDegradation", 0);
					}
				}
			}
			
			Repair.priceMultiplier = Config.Traders.RepairMult;
			trader.fence.assortSize = Config.Traders.FenceAmountOnSale;
			trader.fence.maxPresetsCount = Config.Traders.FencePresetcount
			trader.fence.presetPriceMult = Config.Traders.FencePresetmult
			trader.fence.Blacklist =  Config.Traders.FenceBlacklist;
			trader.minDurabilityForSale = Config.Traders.MinDurabSell
			globals.RagFair.minUserLevel = Config.Traders.FleaMarketLevel;	
			Quest.redeemTime = Config.Traders.QuestRedeemTime;
			trader.updateTimeDefault = Config.Traders.StockTime;

			Inventory.newItemsMarkedFound = Config.Traders.FIRTrade;
			const Mark = Config.Traders.TraderMarkup
			const MarkArray = [Mark.PraporMarkup,
				Mark.TherapistMarkup,
				Mark.FenceMarkup,
				Mark.SkierMarkup,
				Mark.PeacekeeperMarkup,
				Mark.MechanicMarkup,
				Mark.RagmanMarkup,
				Mark.JaegerMarkup
			]
			let i = 0;
			for (let CurTrader in traders)
			{
				if (CurTrader !== "ragfair" && (CurTrader == "5a7c2eca46aef81a7ca2145d" || CurTrader == "5ac3b934156ae10c4430e83c" || CurTrader == "5c0647fdd443bc2504c2d371" || CurTrader == "54cb50c76803fa8b248b4571" || CurTrader == "54cb57776803fa99248b456e" || CurTrader == "579dc571d53a0658a154fbec" || CurTrader == "5935c25fb3acc3127c3d8cd9" || CurTrader == "58330581ace78e27b8b10cee"))
				{
					for (let level in traders[CurTrader].base.loyaltyLevels)
					{
						traders[CurTrader].base.loyaltyLevels[level].buy_price_coef = 100 - MarkArray[i]
					}
					i++
				}
			}
			if (Config.Traders.EnableHealMarkup)
			{
				for (let level in traders["54cb57776803fa99248b456e"].base.loyaltyLevels)
				{
					traders["54cb57776803fa99248b456e"].base.loyaltyLevels[level].heal_price_coef = Config.Traders.HealMarkup.TherapistHealMarkup
				}
			}
			//Enable all the quests
			if (Config.Traders.AllQuestsAvailable)
			{
				Logger.debug("SVM: All Quests are Available");
				for (let id in Quests)
				{
					let QuestData = Quests[id]
					QuestData.conditions.AvailableForStart = [
					{
						"_parent": "Level",
						"_props":
						{
							"compareMethod": ">=",
							"value": "1",
							"index": 0,
							"parentId": "",
							"id": "SVM: AllQuestsAvailable"
						}
					}]
				}
			}
			if (Config.Traders["FIRRestrictsQuests"])
			{
				Logger.debug("SVM: No more FIR requirements in quests");
				for (const id in Quests)
				{
					let condition = Quests[id].conditions.AvailableForFinish
					for (const requirements in condition)
					{
						let requirement = condition[requirements]
						if (requirement._parent == "FindItem" || requirement._parent == "HandoverItem")
						{
							if ('_props' in requirement && 'onlyFoundInRaid' in requirement._props)
							{
								requirement._props.onlyFoundInRaid = false
							}
						}
					}
				}
			}
			//Enable all clothes available for both side
			if (Config.Traders.ClothesAnySide)
			{
				Logger.debug("SVM: All fashion unlocked");
				for (let suit in suits)
				{
					let suitData = suits[suit]
					if (suitData._parent === "5cd944ca1388ce03a44dc2a4" || suitData._parent === "5cd944d01388ce000a659df9")
					{
						suitData._props.Side = ["Bear", "Usec"];
					}
				}
			}
			if (Config.Traders.AllClothesFree)
			{
				for (let tradercloth in traders)
				{
					if (traders[tradercloth].suits)
					{
						for (let file in traders[tradercloth].suits)
						{
							let fileData = traders[tradercloth].suits[file]
							fileData.requirements.loyaltyLevel = 1;
							fileData.requirements.profileLevel = 1;
							fileData.requirements.standing = 0;
							fileData.requirements.skillRequirements = [];
							fileData.requirements.questRequirements = [];
							fileData.requirements.itemRequirements = [];
						}
					}
				}
			}
			//Enable all traders 4 stars
			if (Config.Traders.TradersLvl4)
			{
				Logger.warning("SVM: Lvl 4 Traders activated, be sure to sell each trader something, that way it will work")
				for (var traderID in traders)
				{
					let loyaltyLevels = traders[traderID].base.loyaltyLevels;
					for (let level in loyaltyLevels)
					{
						loyaltyLevels[level].minLevel = 1
						loyaltyLevels[level].minSalesSum = 0
						loyaltyLevels[level].minStanding = 0
					}
				}
			}
			if (Config.Traders.RemoveTradeLimits)
			{
				for (let AssortR in traders)
				{
					if (AssortR !== "ragfair")
					{
						for (let level in traders[AssortR].assort.items)
						{
							if (traders[AssortR].assort.items[level].upd !== undefined && traders[AssortR].assort.items[level].upd["BuyRestrictionMax"] !== undefined)
							{
								delete traders[AssortR].assort.items[level].upd["BuyRestrictionMax"]
							}
						}
					}
				}
			}
		}
		//############## BOTS LOADOUT SECTION ##################, Maybe making it in one JS wasn't such a good idea, but thanks that Ctrl-F exists.
		//I'm too lazy to clean the code for now, i think some shortcuts could be made 
		//The idea would be creating most values into arrays and run them this way rather making direct requests, but hey, at least code is readable
		if (BL.EnableAdvLoad)
		{
			// BL redirects
			const BEAR = Config.BL.BearAdvancedLoadout;
			const USEC = Config.BL.UsecAdvancedLoadout;
			const RAIDER = Config.BL.RaiderAdvancedLoadout;
			const SCAV = Config.BL.ScavAdvancedLoadout;
			const ROGUE = Config.BL.RogueAdvancedLoadout// kinda overkill for 5 variables but made it to make code in BL section readable
			const AddKeys = [];
			const AddContainers = [];
			const CurUsec = "usec"
			const CurBear = "bear"
			const bottypes = [
				CurBear, "assault","cursedassault",
				CurUsec, "pmcbot", "marksman"
			];
			for (const id in items)
			{
				let base = items[id]
				//BL pos
				if ((base._parent === "5c99f98d86f7745c314214b3" || base._parent === "5c164d2286f774194c5e69fa") && Config.BL.AddAllKeys)
				{
					AddKeys.push(base._id)
				}
				if ((base._id === "567143bf4bdc2d1a0f8b4567" || base._parent === "5795f317245977243854e041") && Config.BL.AddAllContainers)
				{
					AddContainers.push(base._id)
				}
				if (base._parent === "5447e1d04bdc2dff2f8b4567" && base._id !== "6087e570b998180e9f76dc24" && Config.BL.LootableMelee)
				{
					EditSimpleItemData(id, "Unlootable", false);
					items[id]._props.UnlootableFromSide = [];
				}
			}
			Logger.debug("SVM: Bots loadouts is on")
			if (Config.BL.AddAllKeys || Config.BL.AddAllContainers)
			{
				for (const i in AddKeys)
				{
					let id = AddKeys[i]
					for (const type in bottypes)
					{
						let role = bottypes[type]
						if (!Bot[role].inventory.items.Pockets[id])
						{
							Bot[role].inventory.items.Pockets.push(id)
						}
					}
				}
				for (const i in AddContainers)
				{
					let id = AddContainers[i]
					for (const type in bottypes)
					{
						let role = bottypes[type]
						if (!Bot[role].inventory.items.Backpack[id])
						{
							Bot[role].inventory.items.Backpack.push(id)
						}
					}
				}
			}
			if (BEAR.BearNamesEnable)
			{
				Bot[CurBear].firstName = BEAR.BearNameList
				Bot[CurBear].lastName = []
			}
			if (USEC.BearNamesEnable)
			{
				Bot[CurUsec].firstName = USEC.UsecNameList
				Bot[CurUsec].lastName = []
			}
			//Change generation values - i really need to automate this process.

				Bot[CurBear].generation.items.healing.min = BEAR.BearHealingMin
				Bot[CurBear].generation.items.healing.max = BEAR.BearHealingMax
				Bot[CurBear].generation.items.looseLoot.min = BEAR.BearLootMin
				Bot[CurBear].generation.items.looseLoot.max = BEAR.BearLootMax
				Bot[CurBear].generation.items.magazines.min = BEAR.BearMagazinesMin
				Bot[CurBear].generation.items.magazines.max = BEAR.BearMagazinesMax
				Bot[CurBear].generation.items.grenades.min = BEAR.BearGrenadesMin
				Bot[CurBear].generation.items.grenades.max = BEAR.BearGrenadesMax

				Bot[CurUsec].generation.items.healing.min = USEC.UsecHealingMin
				Bot[CurUsec].generation.items.healing.max = USEC.UsecHealingMax
				Bot[CurUsec].generation.items.looseLoot.min = USEC.UsecLootMin
				Bot[CurUsec].generation.items.looseLoot.max = USEC.UsecLootMax
				Bot[CurUsec].generation.items.magazines.min = USEC.UsecMagazinesMin
				Bot[CurUsec].generation.items.magazines.max = USEC.UsecMagazinesMax
				Bot[CurUsec].generation.items.grenades.min = USEC.UsecGrenadesMin
				Bot[CurUsec].generation.items.grenades.max = USEC.UsecGrenadesMax

				Bot["assault"].generation.items.healing.min = SCAV.ScavHealingMin
				Bot["assault"].generation.items.healing.max = SCAV.ScavHealingMax
				Bot["assault"].generation.items.looseLoot.min = SCAV.ScavLootMin
				Bot["assault"].generation.items.looseLoot.max = SCAV.ScavLootMax
				Bot["assault"].generation.items.magazines.min = SCAV.ScavMagazinesMin
				Bot["assault"].generation.items.magazines.max = SCAV.ScavMagazinesMax
				Bot["assault"].generation.items.grenades.min = SCAV.ScavGrenadesMin
				Bot["assault"].generation.items.grenades.max = SCAV.ScavGrenadesMax
				
				Bot["cursedassault"].generation.items.healing.min = SCAV.ScavHealingMin
				Bot["cursedassault"].generation.items.healing.max = SCAV.ScavHealingMax
				Bot["cursedassault"].generation.items.looseLoot.min = SCAV.ScavLootMin
				Bot["cursedassault"].generation.items.looseLoot.max = SCAV.ScavLootMax
				Bot["cursedassault"].generation.items.magazines.min = SCAV.ScavMagazinesMin
				Bot["cursedassault"].generation.items.magazines.max = SCAV.ScavMagazinesMax
				Bot["cursedassault"].generation.items.grenades.min = SCAV.ScavGrenadesMin
				Bot["cursedassault"].generation.items.grenades.max = SCAV.ScavGrenadesMax
				
				Bot["marksman"].generation.items.healing.min = SCAV.ScavHealingMin
				Bot["marksman"].generation.items.healing.max = SCAV.ScavHealingMax
				Bot["marksman"].generation.items.looseLoot.min = SCAV.ScavLootMin
				Bot["marksman"].generation.items.looseLoot.max = SCAV.ScavLootMax
				Bot["marksman"].generation.items.magazines.min = SCAV.ScavMagazinesMin
				Bot["marksman"].generation.items.magazines.max = SCAV.ScavMagazinesMax
				Bot["marksman"].generation.items.grenades.min = SCAV.ScavGrenadesMin
				Bot["marksman"].generation.items.grenades.max = SCAV.ScavGrenadesMax
				
				Bot["pmcbot"].generation.items.healing.min = RAIDER.RaiderHealingMin
				Bot["pmcbot"].generation.items.healing.max = RAIDER.RaiderHealingMax
				Bot["pmcbot"].generation.items.looseLoot.min = RAIDER.RaiderLootMin
				Bot["pmcbot"].generation.items.looseLoot.max = RAIDER.RaiderLootMax
				Bot["pmcbot"].generation.items.magazines.min = RAIDER.RaiderMagazinesMin
				Bot["pmcbot"].generation.items.magazines.max = RAIDER.RaiderMagazinesMax
				Bot["pmcbot"].generation.items.grenades.min = RAIDER.RaiderGrenadesMin
				Bot["pmcbot"].generation.items.grenades.max = RAIDER.RaiderGrenadesMax
				
				Bot["exusec"].generation.items.healing.min = ROGUE.RogueHealingMin
				Bot["exusec"].generation.items.healing.max = ROGUE.RogueHealingMax
				Bot["exusec"].generation.items.looseLoot.min = ROGUE.RogueLootMin
				Bot["exusec"].generation.items.looseLoot.max = ROGUE.RogueLootMax
				Bot["exusec"].generation.items.magazines.min = ROGUE.RogueMagazinesMin
				Bot["exusec"].generation.items.magazines.max = ROGUE.RogueMagazinesMax
				Bot["exusec"].generation.items.grenades.min = ROGUE.RogueGrenadesMin
				Bot["exusec"].generation.items.grenades.max = ROGUE.RogueGrenadesMax

				Bot[CurBear].chances.equipment = BEAR.BearEquipmentChanceList
				Bot[CurBear].chances.mods = BEAR.BearAttachmentChanceList

				Bot[CurUsec].chances.equipment = USEC.UsecEquipmentChanceList
				Bot[CurUsec].chances.mods = USEC.UsecAttachmentChanceList

				Bot["pmcbot"].chances.equipment = RAIDER.RaiderEquipmentChanceList
				Bot["pmcbot"].chances.mods = RAIDER.RaiderAttachmentChanceList

				Bot["assault"].chances.equipment = SCAV.ScavEquipmentChanceList
				Bot["assault"].chances.mods = SCAV.ScavAttachmentChanceList
				
				Bot["cursedassault"].chances.equipment = SCAV.ScavEquipmentChanceList
				Bot["cursedassault"].chances.mods = SCAV.ScavAttachmentChanceList
				
				Bot["marksman"].chances.equipment = SCAV.ScavEquipmentChanceList
				Bot["marksman"].chances.mods = SCAV.ScavAttachmentChanceList
				
				Bot["exusec"].chances.equipment = ROGUE.RogueEquipmentChanceList
				Bot["exusec"].chances.mods = ROGUE.RogueAttachmentChanceList
				
		}
		//############## QUESTS ############# It'll be straightforward as possible for now in sake of tests, i may shortify and push an array later.
		//Someone might hate me here in words repetetiveness, but i couldn't do otherwise,the name of the structure is DailyQuests and WeeklyQuests, and then every variable should have unique name
		if (Config.Quests.EnableQuests)
		{
			const Daily = Config.Quests.DailyQuests;
			const Weekly = Config.Quests.WeeklyQuests;
			//Daily
			Quest.repeatableQuests[0].resetTime = Daily.DailyLifespan;
			Quest.repeatableQuests[0].types = Daily.DailyTypes;
			Quest.repeatableQuests[0].numQuests = Daily.DailyQuestAmount;
			Quest.repeatableQuests[0].minPlayerLevel = Daily.DailyAccess;
			Quest.repeatableQuests[0].rewardScaling.levels = Daily.DailyLevels;
			Quest.repeatableQuests[0].rewardScaling.experience = Daily.DailyExp;
			Quest.repeatableQuests[0].rewardScaling.roubles = Daily.DailyRoubles;
			Quest.repeatableQuests[0].rewardScaling.items = Daily.DailyItems;
			Quest.repeatableQuests[0].rewardScaling.reputation = Daily.DailyReputation;
			Quest.repeatableQuests[0].rewardScaling.rewardSpread = Daily.DailySpread;
			Quest.repeatableQuests[0].questConfig.Exploration.maxExtracts = Daily.DailyExtracts;
			Quest.repeatableQuests[0].questConfig.Completion.minRequestedAmount = Daily.DailyMinItems;
			Quest.repeatableQuests[0].questConfig.Completion.maxRequestedAmount = Daily.DailyMaxItems;
			Quest.repeatableQuests[0].questConfig.Completion.useWhitelist = Daily.DailyWhitelist
			Quest.repeatableQuests[0].questConfig.Completion.useBlacklist = Daily.DailyBlacklist
			Quest.repeatableQuests[0].questConfig.Elimination.minKills = Daily.DailyMinKills;
			Quest.repeatableQuests[0].questConfig.Elimination.maxKills = Daily.DailyMaxKills;
			//Weekly
			Quest.repeatableQuests[1].resetTime = Weekly.WeeklyLifespan;
			Quest.repeatableQuests[1].types = Weekly.WeeklyTypes;
			Quest.repeatableQuests[1].numQuests = Weekly.WeeklyQuestAmount;
			Quest.repeatableQuests[1].minPlayerLevel = Weekly.WeeklyAccess;
			Quest.repeatableQuests[1].rewardScaling.levels = Weekly.WeeklyLevels;
			Quest.repeatableQuests[1].rewardScaling.experience = Weekly.WeeklyExp;
			Quest.repeatableQuests[1].rewardScaling.roubles = Weekly.WeeklyRoubles;
			Quest.repeatableQuests[1].rewardScaling.items = Weekly.WeeklyItems;
			Quest.repeatableQuests[1].rewardScaling.reputation = Weekly.WeeklyReputation;
			Quest.repeatableQuests[1].rewardScaling.rewardSpread = Weekly.WeeklySpread;
			Quest.repeatableQuests[1].questConfig.Exploration.maxExtracts = Weekly.WeeklyExtracts;
			Quest.repeatableQuests[1].questConfig.Completion.minRequestedAmount = Weekly.WeeklyMinItems;
			Quest.repeatableQuests[1].questConfig.Completion.maxRequestedAmount = Weekly.WeeklyMaxItems;
			Quest.repeatableQuests[1].questConfig.Completion.useWhitelist = Weekly.WeeklyWhitelist;
			Quest.repeatableQuests[1].questConfig.Completion.useBlacklist = Weekly.WeeklyBlacklist;
			Quest.repeatableQuests[1].questConfig.Elimination.minKills = Weekly.WeeklyMinKills;
			Quest.repeatableQuests[1].questConfig.Elimination.maxKills = Weekly.WeeklyMaxKills;
		}
		//############## FUNCTIONS ##############
		//Set a Unique AI type spawn within selected location, with a lot of variables to come in.
		function CreateBoss(role, chance, followers, escortAmount, zones)
		{
			return {
				"BossName": role,
				"BossChance": chance,
				"BossZone": zones,
				"BossPlayer": false,
				"BossDifficult": "normal",
				"BossEscortType": followers,
				"BossEscortDifficult": "normal",
				"BossEscortAmount": escortAmount,
				"Time": -1
			}
		}
		// 60c7272c204bc17802313365 карманы 1 на 3
		// 557ffd194bdc2d28148b457f 1 на 4
		// 5af99e9186f7747c447120b8 большие
		//Functions overload doesn't exist in JS, i could still make it clearer tho.
		function EditSimpleItemData(id, data, value)
		{
			if (isNaN(value) && value !== 'true' && value !== 'false')
			{
				items[id]._props[data] = value
			}
			else
			{
				items[id]._props[data] = JSON.parse(value)
			}
		}

		function EditAdvancedItemData(id, structure, data, value)
		{
			if (isNaN(value) && value !== 'true' && value !== 'false')
			{
				items[id]._props[structure][data] = value
			}
			else
			{
				items[id]._props[structure][data] = JSON.parse(value)
			}
		}

		function EditEnchancedtemData(id, structure, array, data, value)
		{
			if (isNaN(value) && value !== 'true' && value !== 'false')
			{
				items[id]._props[structure][array][data] = value
			}
			else
			{
				items[id]._props[structure][array][data] = JSON.parse(value)
			}
		}

		function EditComplicatedItemData(id, extstructure, array, intstructure, data, value)
		{
			if (isNaN(value) && value !== 'true' && value !== 'false')
			{
				items[id]._props[extstructure][array][intstructure][data] = value
			}
			else
			{
				items[id]._props[extstructure][array][intstructure][data] = JSON.parse(value)
			}
		}
	}
}
module.exports = {
	mod: new MainSVM
};